@@ -4,12 +4,13 @@ import asyncio
 import calendar
 import datetime
 import time
-from typing import Any
+from typing import Any, cast
 
 from deprecated.sphinx import versionadded
 
 from limits.aio.storage.base import MovingWindowSupport, Storage
-from limits.typing import Dict, Optional, ParamSpec, Tuple, TypeVar, Union
+from limits.typing import Dict, Optional, ParamSpec, Tuple, Type, TypeVar, Union
+from limits.util import get_dependency
 
 P = ParamSpec("P")
 R = TypeVar("R")
@@ -28,18 +29,13 @@ class MongoDBStorage(Storage, MovingWindowSupport):
     The storage scheme for MongoDB for use in an async context
     """
 
-    DEFAULT_OPTIONS: Dict[str, Union[float, str, bool]] = {
-        "serverSelectionTimeoutMS": 1000,
-        "connectTimeoutMS": 1000,
-    }
-    "Default options passed to :class:`~motor.motor_asyncio.AsyncIOMotorClient`"
-
     DEPENDENCIES = ["motor.motor_asyncio", "pymongo"]
 
     def __init__(
         self,
         uri: str,
         database_name: str = "limits",
+        wrap_exceptions: bool = False,
         **options: Union[float, str, bool],
     ) -> None:
         """
@@ -47,23 +43,23 @@ class MongoDBStorage(Storage, MovingWindowSupport):
          This uri is passed directly to :class:`~motor.motor_asyncio.AsyncIOMotorClient`
         :param database_name: The database to use for storing the rate limit
          collections.
-        :param options: all remaining keyword arguments are merged with
-         :data:`DEFAULT_OPTIONS` and passed to the constructor of
-         :class:`~motor.motor_asyncio.AsyncIOMotorClient`
+        :param wrap_exceptions: Whether to wrap storage exceptions in
+         :exc:`limits.errors.StorageError` before raising it.
+        :param options: all remaining keyword arguments are passed
+         to the constructor of :class:`~motor.motor_asyncio.AsyncIOMotorClient`
         :raise ConfigurationError: when the :pypi:`motor` or :pypi:`pymongo` are
          not available
         """
 
-        mongo_opts = options.copy()
-        [mongo_opts.setdefault(k, v) for k, v in self.DEFAULT_OPTIONS.items()]
         uri = uri.replace("async+mongodb", "mongodb", 1)
 
-        super().__init__(uri, **options)
+        super().__init__(uri, wrap_exceptions=wrap_exceptions, **options)
 
         self.dependency = self.dependencies["motor.motor_asyncio"]
         self.proxy_dependency = self.dependencies["pymongo"]
+        self.lib_errors, _ = get_dependency("pymongo.errors")
 
-        self.storage = self.dependency.module.AsyncIOMotorClient(uri, **mongo_opts)
+        self.storage = self.dependency.module.AsyncIOMotorClient(uri, **options)
         # TODO: Fix this hack. It was noticed when running a benchmark
         # with FastAPI - however - doesn't appear in unit tests or in an isolated
         # use. Reference: https://jira.mongodb.org/browse/MOTOR-822
@@ -72,6 +68,12 @@ class MongoDBStorage(Storage, MovingWindowSupport):
         self.__database_name = database_name
         self.__indices_created = False
 
+    @property
+    def base_exceptions(
+        self,
+    ) -> Union[Type[Exception], Tuple[Type[Exception], ...]]:  # pragma: no cover
+        return self.lib_errors.PyMongoError  # type: ignore
+
     @property
     def database(self):  # type: ignore
         return self.storage.get_database(self.__database_name)
@@ -98,7 +100,7 @@ class MongoDBStorage(Storage, MovingWindowSupport):
             self.database.counters.drop(), self.database.windows.drop()
         )
 
-        return num_keys
+        return cast(int, num_keys)
 
     async def clear(self, key: str) -> None:
         """
@@ -114,7 +116,11 @@ class MongoDBStorage(Storage, MovingWindowSupport):
         :param key: the key to get the expiry for
         """
         counter = await self.database.counters.find_one({"_id": key})
-        expiry = counter["expireAt"] if counter else datetime.datetime.utcnow()
+        expiry = (
+            counter["expireAt"]
+            if counter
+            else datetime.datetime.now(datetime.timezone.utc)
+        )
 
         return calendar.timegm(expiry.timetuple())
 
@@ -123,7 +129,10 @@ class MongoDBStorage(Storage, MovingWindowSupport):
         :param key: the key to get the counter value for
         """
         counter = await self.database.counters.find_one(
-            {"_id": key, "expireAt": {"$gte": datetime.datetime.utcnow()}},
+            {
+                "_id": key,
+                "expireAt": {"$gte": datetime.datetime.now(datetime.timezone.utc)},
+            },
             projection=["count"],
         )
 
@@ -143,7 +152,9 @@ class MongoDBStorage(Storage, MovingWindowSupport):
         """
         await self.create_indices()
 
-        expiration = datetime.datetime.utcnow() + datetime.timedelta(seconds=expiry)
+        expiration = datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(
+            seconds=expiry
+        )
 
         response = await self.database.counters.find_one_and_update(
             {"_id": key},
@@ -216,7 +227,7 @@ class MongoDBStorage(Storage, MovingWindowSupport):
                 {
                     "$group": {
                         "_id": "$_id",
-                        "max": {"$max": "$entries"},
+                        "min": {"$min": "$entries"},
                         "count": {"$sum": 1},
                     }
                 },
@@ -224,7 +235,7 @@ class MongoDBStorage(Storage, MovingWindowSupport):
         ).to_list(length=1)
 
         if result:
-            return (int(result[0]["max"]), result[0]["count"])
+            return (int(result[0]["min"]), result[0]["count"])
 
         return (int(timestamp), 0)
 
@@ -250,15 +261,17 @@ class MongoDBStorage(Storage, MovingWindowSupport):
 
             updates["$set"] = {
                 "expireAt": (
-                    datetime.datetime.utcnow() + datetime.timedelta(seconds=expiry)
+                    datetime.datetime.now(datetime.timezone.utc)
+                    + datetime.timedelta(seconds=expiry)
                 )
             }
             updates["$push"]["entries"]["$each"] = [timestamp] * amount
             await self.database.windows.update_one(
                 {
                     "_id": key,
-                    "entries.%d"
-                    % (limit - amount): {"$not": {"$gte": timestamp - expiry}},
+                    "entries.%d" % (limit - amount): {
+                        "$not": {"$gte": timestamp - expiry}
+                    },
                 },
                 updates,
                 upsert=True,
