@@ -29,7 +29,8 @@ class RedisSentinelStorage(RedisStorage):
         service_name: Optional[str] = None,
         use_replicas: bool = True,
         sentinel_kwargs: Optional[Dict[str, Union[float, str, bool]]] = None,
-        **options: Union[float, str, bool]
+        wrap_exceptions: bool = False,
+        **options: Union[float, str, bool],
     ) -> None:
         """
         :param uri: url of the form
@@ -39,13 +40,17 @@ class RedisSentinelStorage(RedisStorage):
         :param use_replicas: Whether to use replicas for read only operations
         :param sentinel_kwargs: kwargs to pass as
          :attr:`sentinel_kwargs` to :class:`redis.sentinel.Sentinel`
+        :param wrap_exceptions: Whether to wrap storage exceptions in
+         :exc:`limits.errors.StorageError` before raising it.
         :param options: all remaining keyword arguments are passed
          directly to the constructor of :class:`redis.sentinel.Sentinel`
         :raise ConfigurationError: when the redis library is not available
          or if the redis master host cannot be pinged.
         """
 
-        super(RedisStorage, self).__init__(uri, **options)
+        super(RedisStorage, self).__init__(
+            uri, wrap_exceptions=wrap_exceptions, **options
+        )
 
         parsed = urllib.parse.urlparse(uri)
         sentinel_configuration = []
@@ -74,7 +79,7 @@ class RedisSentinelStorage(RedisStorage):
         self.sentinel: "redis.sentinel.Sentinel" = sentinel_dep.Sentinel(
             sentinel_configuration,
             sentinel_kwargs={**parsed_auth, **sentinel_options},
-            **{**parsed_auth, **options}
+            **{**parsed_auth, **options},
         )
         self.storage = self.sentinel.master_for(self.service_name)
         self.storage_slave = self.sentinel.slave_for(self.service_name)
